
/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton implementation for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "2.4.1"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Copy the first part of user declarations.  */

/* Line 189 of yacc.c  */
#line 22 "parser.yy"


#include <iostream>
#include <cstdio>
#include <string>
#include <cstring>
#include "genparse.h"
#include "clparam_list.h"
#include "logfile.h"
#include "unique_int.h"

#define YYDEBUG 1

// These  prototypes are necessary for C++ compilation
int yyerror (char *);
int yylex ();
void dump_short_reps (char *);
void add_param_to_list ();
void dump_param_type (param_type);

// These are all defined in genparse.cc
extern Clparam_list *my_params;
extern Unique_Int longopt_value;
extern Logfile mylog;
extern int yylineno;
extern char *yyfilename;

// This is an object we use over and over to read in parameters
Clparam *param;



/* Line 189 of yacc.c  */
#line 106 "parser.cc"

/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* Enabling the token table.  */
#ifndef YYTOKEN_TABLE
# define YYTOKEN_TABLE 0
#endif


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SLASH = 258,
     RANGE_SPEC1 = 259,
     RANGE_SPEC2 = 260,
     FUNC_SPEC = 261,
     NONE = 262,
     OPEN_BRACE = 263,
     CLOSE_BRACE = 264,
     OPEN_SQUARE_BRACE = 265,
     CLOSE_SQUARE_BRACE = 266,
     EQUAL = 267,
     INCLUDE = 268,
     LT = 269,
     GT = 270,
     MANDATORY = 271,
     EXIT_VALUE = 272,
     BREAK_LINES = 273,
     DOUBLEQUOTE = 274,
     ASTERISK = 275,
     EXCLAMATIONMARK = 276,
     STORE_LONGINDEX = 277,
     EXPORT_LONG_OPTIONS = 278,
     GP_INCLUDE = 279,
     ERR_MSG = 280,
     COMMENT = 281,
     DO_NOT_DOCUMENT = 282,
     OPEN_ROUND_BRACE = 283,
     CLOSE_ROUND_BRACE = 284,
     COLON = 285,
     ADD_FLAG = 286,
     NO_STRUCT = 287,
     CODE_END = 288,
     QUOTED = 289,
     FIRST_QUOTED = 290,
     C_VAR = 291,
     ALNUM = 292,
     FILENAME = 293,
     CHAR_VAL = 294,
     FIRST_STR = 295,
     USAGE_LINE = 296,
     CODE_LINE = 297,
     OPT_NAME = 298,
     COMMENT_STR = 299,
     FUNCTION = 300,
     FLAG = 301,
     INT = 302,
     LONG = 303,
     ULONG = 304,
     INTMAX = 305,
     UINTMAX = 306,
     FLOAT = 307,
     DOUBLE = 308,
     CHAR = 309,
     STRING = 310
   };
#endif
/* Tokens.  */
#define SLASH 258
#define RANGE_SPEC1 259
#define RANGE_SPEC2 260
#define FUNC_SPEC 261
#define NONE 262
#define OPEN_BRACE 263
#define CLOSE_BRACE 264
#define OPEN_SQUARE_BRACE 265
#define CLOSE_SQUARE_BRACE 266
#define EQUAL 267
#define INCLUDE 268
#define LT 269
#define GT 270
#define MANDATORY 271
#define EXIT_VALUE 272
#define BREAK_LINES 273
#define DOUBLEQUOTE 274
#define ASTERISK 275
#define EXCLAMATIONMARK 276
#define STORE_LONGINDEX 277
#define EXPORT_LONG_OPTIONS 278
#define GP_INCLUDE 279
#define ERR_MSG 280
#define COMMENT 281
#define DO_NOT_DOCUMENT 282
#define OPEN_ROUND_BRACE 283
#define CLOSE_ROUND_BRACE 284
#define COLON 285
#define ADD_FLAG 286
#define NO_STRUCT 287
#define CODE_END 288
#define QUOTED 289
#define FIRST_QUOTED 290
#define C_VAR 291
#define ALNUM 292
#define FILENAME 293
#define CHAR_VAL 294
#define FIRST_STR 295
#define USAGE_LINE 296
#define CODE_LINE 297
#define OPT_NAME 298
#define COMMENT_STR 299
#define FUNCTION 300
#define FLAG 301
#define INT 302
#define LONG 303
#define ULONG 304
#define INTMAX 305
#define UINTMAX 306
#define FLOAT 307
#define DOUBLE 308
#define CHAR 309
#define STRING 310




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 214 of yacc.c  */
#line 57 "parser.yy"

  char    *str;  /* string */
  int     i;
  param_type p;



/* Line 214 of yacc.c  */
#line 260 "parser.cc"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif


/* Copy the second part of user declarations.  */


/* Line 264 of yacc.c  */
#line 272 "parser.cc"

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#elif (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
typedef signed char yytype_int8;
#else
typedef short int yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(msgid) dgettext ("bison-runtime", msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(msgid) msgid
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(e) ((void) (e))
#else
# define YYUSE(e) /* empty */
#endif

/* Identity function, used to suppress warnings about constant conditions.  */
#ifndef lint
# define YYID(n) (n)
#else
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static int
YYID (int yyi)
#else
static int
YYID (yyi)
    int yyi;
#endif
{
  return yyi;
}
#endif

#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#     ifndef _STDLIB_H
#      define _STDLIB_H 1
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (YYID (0))
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined _STDLIB_H \
       && ! ((defined YYMALLOC || defined malloc) \
	     && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef _STDLIB_H
#    define _STDLIB_H 1
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
	 || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  YYSIZE_T yyi;				\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (YYID (0))
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
	Stack = &yyptr->Stack_alloc;					\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (YYID (0))

#endif

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  26
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   125

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  56
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  42
/* YYNRULES -- Number of rules.  */
#define YYNRULES  103
/* YYNRULES -- Number of states.  */
#define YYNSTATES  137

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   310

#define YYTRANSLATE(YYX)						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const yytype_uint16 yyprhs[] =
{
       0,     0,     3,     7,    10,    11,    14,    16,    18,    20,
      22,    24,    26,    28,    30,    35,    40,    43,    46,    49,
      52,    54,    56,    58,    61,    63,    64,    67,    69,    73,
      74,    77,    79,    81,    83,    85,    87,    89,    91,    93,
      95,    97,    99,   102,   104,   109,   111,   113,   117,   121,
     126,   129,   131,   135,   139,   141,   144,   147,   149,   152,
     155,   158,   161,   165,   167,   170,   173,   175,   177,   179,
     181,   183,   185,   187,   189,   191,   193,   195,   197,   199,
     201,   205,   209,   213,   216,   218,   220,   221,   223,   225,
     228,   230,   232,   233,   236,   238,   240,   243,   245,   248,
     250,   252,   254,   256
};

/* YYRHS -- A `-1'-separated list of the rules' RHS.  */
static const yytype_int8 yyrhs[] =
{
      57,     0,    -1,    58,    67,    93,    -1,    58,    93,    -1,
      -1,    58,    59,    -1,    59,    -1,    60,    -1,    61,    -1,
      62,    -1,    63,    -1,    64,    -1,    65,    -1,    66,    -1,
      13,    14,    38,    15,    -1,    13,    19,    38,    19,    -1,
      16,    36,    -1,    17,    36,    -1,    17,    37,    -1,    18,
      37,    -1,    23,    -1,    32,    -1,    91,    -1,    67,    68,
      -1,    68,    -1,    -1,    69,    70,    -1,    77,    -1,    78,
      85,    71,    -1,    -1,    71,    72,    -1,    72,    -1,    86,
      -1,    87,    -1,    91,    -1,    73,    -1,    22,    -1,    74,
      -1,    31,    -1,    27,    -1,    76,    -1,    95,    -1,    73,
      92,    -1,    92,    -1,    25,    28,    75,    29,    -1,    37,
      -1,    34,    -1,    37,    30,    36,    -1,    34,    30,    36,
      -1,    26,    28,    44,    29,    -1,    24,    38,    -1,    79,
      -1,     7,     3,    80,    -1,    79,     3,    80,    -1,    40,
      -1,    40,    20,    -1,    40,    21,    -1,    83,    -1,    83,
      81,    -1,    83,    82,    -1,    12,    36,    -1,    12,    43,
      -1,    10,    81,    11,    -1,    84,    -1,    84,    20,    -1,
      84,    21,    -1,    37,    -1,    36,    -1,    47,    -1,    48,
      -1,    49,    -1,    50,    -1,    51,    -1,    52,    -1,    53,
      -1,    55,    -1,    54,    -1,    46,    -1,    37,    -1,    39,
      -1,     8,    34,     9,    -1,    10,    88,    11,    -1,    37,
      90,    89,    -1,    90,    89,    -1,    37,    -1,    36,    -1,
      -1,     4,    -1,     5,    -1,    45,     6,    -1,    34,    -1,
      35,    -1,    -1,    93,    94,    -1,    94,    -1,    41,    -1,
      95,    96,    -1,    96,    -1,    97,    33,    -1,    33,    -1,
      42,    -1,    28,    -1,    29,    -1,    97,    97,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,    81,    81,    82,    85,    86,    87,    90,    91,    92,
      93,    94,    95,    96,    99,   105,   113,   121,   127,   135,
     143,   150,   157,   164,   165,   169,   169,   176,   179,   186,
     187,   188,   191,   197,   198,   203,   204,   209,   210,   215,
     220,   221,   224,   225,   228,   231,   238,   245,   255,   266,
     273,   280,   287,   292,   300,   301,   305,   311,   312,   313,
     316,   321,   328,   334,   335,   339,   345,   351,   359,   360,
     368,   376,   384,   392,   393,   401,   402,   403,   406,   407,
     408,   411,   414,   420,   424,   430,   436,   439,   440,   443,
     446,   452,   460,   461,   462,   465,   473,   474,   477,   483,
     490,   493,   497,   501
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "SLASH", "RANGE_SPEC1", "RANGE_SPEC2",
  "FUNC_SPEC", "NONE", "OPEN_BRACE", "CLOSE_BRACE", "OPEN_SQUARE_BRACE",
  "CLOSE_SQUARE_BRACE", "EQUAL", "INCLUDE", "LT", "GT", "MANDATORY",
  "EXIT_VALUE", "BREAK_LINES", "DOUBLEQUOTE", "ASTERISK",
  "EXCLAMATIONMARK", "STORE_LONGINDEX", "EXPORT_LONG_OPTIONS",
  "GP_INCLUDE", "ERR_MSG", "COMMENT", "DO_NOT_DOCUMENT",
  "OPEN_ROUND_BRACE", "CLOSE_ROUND_BRACE", "COLON", "ADD_FLAG",
  "NO_STRUCT", "CODE_END", "QUOTED", "FIRST_QUOTED", "C_VAR", "ALNUM",
  "FILENAME", "CHAR_VAL", "FIRST_STR", "USAGE_LINE", "CODE_LINE",
  "OPT_NAME", "COMMENT_STR", "FUNCTION", "FLAG", "INT", "LONG", "ULONG",
  "INTMAX", "UINTMAX", "FLOAT", "DOUBLE", "CHAR", "STRING", "$accept",
  "all", "globals", "global", "include", "mandatory", "exit_value",
  "break_lines", "export_long_options", "no_struct", "global_callback",
  "entries", "entry", "$@1", "new_entry", "options", "option", "descs",
  "err_msg", "err_msg_arg", "comment", "gp_include", "param",
  "short_params", "long_param", "mandatory_opt_name", "optional_opt_name",
  "multi_long_option", "long_option", "type", "default", "range",
  "contiguous_range", "more_range", "range_spec", "callback", "desc",
  "usages", "usage", "code_lines", "code_line", "single_code_line", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309,   310
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    56,    57,    57,    58,    58,    58,    59,    59,    59,
      59,    59,    59,    59,    60,    60,    61,    62,    62,    63,
      64,    65,    66,    67,    67,    69,    68,    68,    70,    71,
      71,    71,    72,    72,    72,    72,    72,    72,    72,    72,
      72,    72,    73,    73,    74,    75,    75,    75,    75,    76,
      77,    78,    78,    78,    79,    79,    79,    80,    80,    80,
      81,    81,    82,    83,    83,    83,    84,    84,    85,    85,
      85,    85,    85,    85,    85,    85,    85,    85,    86,    86,
      86,    87,    88,    88,    89,    89,    89,    90,    90,    91,
      92,    92,    93,    93,    93,    94,    95,    95,    96,    96,
      97,    97,    97,    97
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     3,     2,     0,     2,     1,     1,     1,     1,
       1,     1,     1,     1,     4,     4,     2,     2,     2,     2,
       1,     1,     1,     2,     1,     0,     2,     1,     3,     0,
       2,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     2,     1,     4,     1,     1,     3,     3,     4,
       2,     1,     3,     3,     1,     2,     2,     1,     2,     2,
       2,     2,     3,     1,     2,     2,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       3,     3,     3,     2,     1,     1,     0,     1,     1,     2,
       1,     1,     0,     2,     1,     1,     2,     1,     2,     1,
       1,     1,     1,     2
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       4,     0,     0,     0,     0,    20,    21,     0,     0,    25,
       6,     7,     8,     9,    10,    11,    12,    13,    22,     0,
       0,    16,    17,    18,    19,    89,     1,     0,    95,     5,
      25,    24,     0,    27,     3,    94,     0,     0,    50,    23,
       2,     0,    54,    26,     0,    51,    93,    14,    15,     0,
      55,    56,    77,    68,    69,    70,    71,    72,    73,    74,
      76,    75,    29,     0,    67,    66,    52,    57,    63,     0,
       0,    36,     0,     0,    39,   101,   102,    38,    99,    90,
      91,    78,    79,   100,    28,    31,    35,    37,    40,    32,
      33,    34,    43,    41,    97,     0,    53,     0,     0,    58,
      59,    64,    65,     0,    87,    88,     0,     0,    86,     0,
       0,    30,    42,    96,    98,   103,     0,    60,    61,    80,
      86,    81,    85,    84,    83,    46,    45,     0,     0,    62,
      82,     0,     0,    44,    49,    48,    47
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int8 yydefgoto[] =
{
      -1,     8,     9,    10,    11,    12,    13,    14,    15,    16,
      17,    30,    31,    32,    43,    84,    85,    86,    87,   127,
      88,    33,    44,    45,    66,    99,   100,    67,    68,    62,
      89,    90,   107,   124,   108,    18,    92,    34,    35,    93,
      94,    95
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -90
static const yytype_int8 yypact[] =
{
      51,    19,   -26,    34,   -17,   -90,   -90,    16,    61,     0,
     -90,   -90,   -90,   -90,   -90,   -90,   -90,   -90,   -90,    27,
      59,   -90,   -90,   -90,   -90,   -90,   -90,    60,   -90,   -90,
       1,   -90,    -3,   -90,    -7,   -90,    42,    80,   -90,   -90,
      -7,    97,    52,   -90,    38,    98,   -90,   -90,   -90,    39,
     -90,   -90,   -90,   -90,   -90,   -90,   -90,   -90,   -90,   -90,
     -90,   -90,    21,    39,   -90,   -90,   -90,    -1,    57,    68,
      -2,   -90,    75,    76,   -90,   -90,   -90,   -90,   -90,   -90,
     -90,   -90,   -90,   -90,    21,   -90,    45,   -90,   -90,   -90,
     -90,   -90,   -90,   -21,   -90,   -14,   -90,    93,     8,   -90,
     -90,   -90,   -90,    99,   -90,   -90,    77,    95,    58,    25,
      63,   -90,   -90,   -90,   -90,    11,   100,   -90,   -90,   -90,
      58,   -90,   -90,   -90,   -90,    79,    82,    81,    84,   -90,
     -90,    78,    83,   -90,   -90,   -90,   -90
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int8 yypgoto[] =
{
     -90,   -90,   -90,   106,   -90,   -90,   -90,   -90,   -90,   -90,
     -90,   -90,    86,   -90,   -90,   -90,    33,   -90,   -90,   -90,
     -90,   -90,   -90,   -90,    55,    23,   -90,   -90,   -90,   -90,
     -90,   -90,   -90,     2,    15,   -57,    37,    94,    -4,   -90,
      32,   -89
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -93
static const yytype_int16 yytable[] =
{
     -92,   -92,   104,   105,    41,    91,   115,    75,    76,    97,
      21,    98,    78,     1,    75,    76,     2,     3,     4,   114,
      24,    83,    25,     5,    27,    27,   115,    91,    83,    69,
      46,    70,     6,    19,    28,   106,    46,    42,    20,    75,
      76,    28,    28,    71,   117,     7,    72,    73,    74,    75,
      76,   118,    77,    83,    78,    79,    80,    47,    81,   125,
      82,    26,   126,    83,     1,    36,     7,     2,     3,     4,
      22,    23,    50,    51,     5,    64,    65,   101,   102,    79,
      80,   104,   105,     6,    52,    53,    54,    55,    56,    57,
      58,    59,    60,    61,   122,   123,     7,    37,    38,    48,
      49,    63,   103,   109,   110,    98,   121,   128,   119,   131,
     133,   129,   132,   134,   135,    29,    39,   111,    96,   136,
     116,   120,   130,   112,    40,   113
};

static const yytype_uint8 yycheck[] =
{
       0,     0,     4,     5,     7,    62,    95,    28,    29,    10,
      36,    12,    33,    13,    28,    29,    16,    17,    18,    33,
      37,    42,     6,    23,    24,    24,   115,    84,    42,     8,
      34,    10,    32,    14,    41,    37,    40,    40,    19,    28,
      29,    41,    41,    22,    36,    45,    25,    26,    27,    28,
      29,    43,    31,    42,    33,    34,    35,    15,    37,    34,
      39,     0,    37,    42,    13,    38,    45,    16,    17,    18,
      36,    37,    20,    21,    23,    36,    37,    20,    21,    34,
      35,     4,     5,    32,    46,    47,    48,    49,    50,    51,
      52,    53,    54,    55,    36,    37,    45,    38,    38,    19,
       3,     3,    34,    28,    28,    12,    11,    44,     9,    30,
      29,    11,    30,    29,    36,     9,    30,    84,    63,    36,
      97,   106,   120,    86,    30,    93
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,    13,    16,    17,    18,    23,    32,    45,    57,    58,
      59,    60,    61,    62,    63,    64,    65,    66,    91,    14,
      19,    36,    36,    37,    37,     6,     0,    24,    41,    59,
      67,    68,    69,    77,    93,    94,    38,    38,    38,    68,
      93,     7,    40,    70,    78,    79,    94,    15,    19,     3,
      20,    21,    46,    47,    48,    49,    50,    51,    52,    53,
      54,    55,    85,     3,    36,    37,    80,    83,    84,     8,
      10,    22,    25,    26,    27,    28,    29,    31,    33,    34,
      35,    37,    39,    42,    71,    72,    73,    74,    76,    86,
      87,    91,    92,    95,    96,    97,    80,    10,    12,    81,
      82,    20,    21,    34,     4,     5,    37,    88,    90,    28,
      28,    72,    92,    96,    33,    97,    81,    36,    43,     9,
      90,    11,    36,    37,    89,    34,    37,    75,    44,    11,
      89,    30,    30,    29,    29,    36,    36
};

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrorlab


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK (1);						\
      goto yybackup;						\
    }								\
  else								\
    {								\
      yyerror (YY_("syntax error: cannot back up")); \
      YYERROR;							\
    }								\
while (YYID (0))


#define YYTERROR	1
#define YYERRCODE	256


/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

#define YYRHSLOC(Rhs, K) ((Rhs)[K])
#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)				\
    do									\
      if (YYID (N))                                                    \
	{								\
	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
	}								\
      else								\
	{								\
	  (Current).first_line   = (Current).last_line   =		\
	    YYRHSLOC (Rhs, 0).last_line;				\
	  (Current).first_column = (Current).last_column =		\
	    YYRHSLOC (Rhs, 0).last_column;				\
	}								\
    while (YYID (0))
#endif


/* YY_LOCATION_PRINT -- Print the location on the stream.
   This macro was not mandated originally: define only if we know
   we won't break user code: when these are the locations we know.  */

#ifndef YY_LOCATION_PRINT
# if YYLTYPE_IS_TRIVIAL
#  define YY_LOCATION_PRINT(File, Loc)			\
     fprintf (File, "%d.%d-%d.%d",			\
	      (Loc).first_line, (Loc).first_column,	\
	      (Loc).last_line,  (Loc).last_column)
# else
#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
# endif
#endif


/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (YYID (0))

# define YY_SYMBOL_PRINT(Title, Type, Value, Location)			  \
do {									  \
  if (yydebug)								  \
    {									  \
      YYFPRINTF (stderr, "%s ", Title);					  \
      yy_symbol_print (stderr,						  \
		  Type, Value); \
      YYFPRINTF (stderr, "\n");						  \
    }									  \
} while (YYID (0))


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_value_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# else
  YYUSE (yyoutput);
# endif
  switch (yytype)
    {
      default:
	break;
    }
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (yytype < YYNTOKENS)
    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
#else
static void
yy_stack_print (yybottom, yytop)
    yytype_int16 *yybottom;
    yytype_int16 *yytop;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (YYID (0))


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_reduce_print (YYSTYPE *yyvsp, int yyrule)
#else
static void
yy_reduce_print (yyvsp, yyrule)
    YYSTYPE *yyvsp;
    int yyrule;
#endif
{
  int yynrhs = yyr2[yyrule];
  int yyi;
  unsigned long int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
	     yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
		       &(yyvsp[(yyi + 1) - (yynrhs)])
		       		       );
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (yyvsp, Rule); \
} while (YYID (0))

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static YYSIZE_T
yystrlen (const char *yystr)
#else
static YYSIZE_T
yystrlen (yystr)
    const char *yystr;
#endif
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static char *
yystpcpy (char *yydest, const char *yysrc)
#else
static char *
yystpcpy (yydest, yysrc)
    char *yydest;
    const char *yysrc;
#endif
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
	switch (*++yyp)
	  {
	  case '\'':
	  case ',':
	    goto do_not_strip_quotes;

	  case '\\':
	    if (*++yyp != '\\')
	      goto do_not_strip_quotes;
	    /* Fall through.  */
	  default:
	    if (yyres)
	      yyres[yyn] = *yyp;
	    yyn++;
	    break;

	  case '"':
	    if (yyres)
	      yyres[yyn] = '\0';
	    return yyn;
	  }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into YYRESULT an error message about the unexpected token
   YYCHAR while in state YYSTATE.  Return the number of bytes copied,
   including the terminating null byte.  If YYRESULT is null, do not
   copy anything; just return the number of bytes that would be
   copied.  As a special case, return 0 if an ordinary "syntax error"
   message will do.  Return YYSIZE_MAXIMUM if overflow occurs during
   size calculation.  */
static YYSIZE_T
yysyntax_error (char *yyresult, int yystate, int yychar)
{
  int yyn = yypact[yystate];

  if (! (YYPACT_NINF < yyn && yyn <= YYLAST))
    return 0;
  else
    {
      int yytype = YYTRANSLATE (yychar);
      YYSIZE_T yysize0 = yytnamerr (0, yytname[yytype]);
      YYSIZE_T yysize = yysize0;
      YYSIZE_T yysize1;
      int yysize_overflow = 0;
      enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
      char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
      int yyx;

# if 0
      /* This is so xgettext sees the translatable formats that are
	 constructed on the fly.  */
      YY_("syntax error, unexpected %s");
      YY_("syntax error, unexpected %s, expecting %s");
      YY_("syntax error, unexpected %s, expecting %s or %s");
      YY_("syntax error, unexpected %s, expecting %s or %s or %s");
      YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
# endif
      char *yyfmt;
      char const *yyf;
      static char const yyunexpected[] = "syntax error, unexpected %s";
      static char const yyexpecting[] = ", expecting %s";
      static char const yyor[] = " or %s";
      char yyformat[sizeof yyunexpected
		    + sizeof yyexpecting - 1
		    + ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
		       * (sizeof yyor - 1))];
      char const *yyprefix = yyexpecting;

      /* Start YYX at -YYN if negative to avoid negative indexes in
	 YYCHECK.  */
      int yyxbegin = yyn < 0 ? -yyn : 0;

      /* Stay within bounds of both yycheck and yytname.  */
      int yychecklim = YYLAST - yyn + 1;
      int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
      int yycount = 1;

      yyarg[0] = yytname[yytype];
      yyfmt = yystpcpy (yyformat, yyunexpected);

      for (yyx = yyxbegin; yyx < yyxend; ++yyx)
	if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	  {
	    if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
	      {
		yycount = 1;
		yysize = yysize0;
		yyformat[sizeof yyunexpected - 1] = '\0';
		break;
	      }
	    yyarg[yycount++] = yytname[yyx];
	    yysize1 = yysize + yytnamerr (0, yytname[yyx]);
	    yysize_overflow |= (yysize1 < yysize);
	    yysize = yysize1;
	    yyfmt = yystpcpy (yyfmt, yyprefix);
	    yyprefix = yyor;
	  }

      yyf = YY_(yyformat);
      yysize1 = yysize + yystrlen (yyf);
      yysize_overflow |= (yysize1 < yysize);
      yysize = yysize1;

      if (yysize_overflow)
	return YYSIZE_MAXIMUM;

      if (yyresult)
	{
	  /* Avoid sprintf, as that infringes on the user's name space.
	     Don't have undefined behavior even if the translation
	     produced a string with the wrong number of "%s"s.  */
	  char *yyp = yyresult;
	  int yyi = 0;
	  while ((*yyp = *yyf) != '\0')
	    {
	      if (*yyp == '%' && yyf[1] == 's' && yyi < yycount)
		{
		  yyp += yytnamerr (yyp, yyarg[yyi++]);
		  yyf += 2;
		}
	      else
		{
		  yyp++;
		  yyf++;
		}
	    }
	}
      return yysize;
    }
}
#endif /* YYERROR_VERBOSE */


/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yymsg, yytype, yyvaluep)
    const char *yymsg;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  YYUSE (yyvaluep);

  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  switch (yytype)
    {

      default:
	break;
    }
}

/* Prevent warnings from -Wmissing-prototypes.  */
#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int yyparse (void *YYPARSE_PARAM);
#else
int yyparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */


/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;



/*-------------------------.
| yyparse or yypush_parse.  |
`-------------------------*/

#ifdef YYPARSE_PARAM
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void *YYPARSE_PARAM)
#else
int
yyparse (YYPARSE_PARAM)
    void *YYPARSE_PARAM;
#endif
#else /* ! YYPARSE_PARAM */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{


    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       `yyss': related to states.
       `yyvs': related to semantic values.

       Refer to the stacks thru separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yytoken = 0;
  yyss = yyssa;
  yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */
  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack.  Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	yytype_int16 *yyss1 = yyss;

	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow (YY_("memory exhausted"),
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),
		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	yytype_int16 *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyexhaustedlab;
	YYSTACK_RELOCATE (yyss_alloc, yyss);
	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  *++yyvsp = yylval;

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 14:

/* Line 1455 of yacc.c  */
#line 100 "parser.yy"
    {
		my_params->add_include ((string)"<" + (yyvsp[(3) - (4)].str) + ">");
		mylog.write ((string) "adding include file: <" + (yyvsp[(3) - (4)].str) + ">");
		free ((yyvsp[(3) - (4)].str));
	}
    break;

  case 15:

/* Line 1455 of yacc.c  */
#line 106 "parser.yy"
    {
		my_params->add_include ((string)"\"" + (yyvsp[(3) - (4)].str) + "\"");
		mylog.write ((string) "adding include file: \"" + (yyvsp[(3) - (4)].str) + "\"");
		free ((yyvsp[(3) - (4)].str));
	}
    break;

  case 16:

/* Line 1455 of yacc.c  */
#line 114 "parser.yy"
    {
		my_params->add_mandatory ((yyvsp[(2) - (2)].str));
		mylog.write ((string) "adding mandatory: " + (yyvsp[(2) - (2)].str));
		free ((yyvsp[(2) - (2)].str));
	}
    break;

  case 17:

/* Line 1455 of yacc.c  */
#line 122 "parser.yy"
    {
		my_params->set_exit_value ((yyvsp[(2) - (2)].str));
		mylog.write ((string) "adding exit value: " + (yyvsp[(2) - (2)].str));
		free ((yyvsp[(2) - (2)].str));
	}
    break;

  case 18:

/* Line 1455 of yacc.c  */
#line 128 "parser.yy"
    {
		my_params->set_exit_value ((yyvsp[(2) - (2)].str));
		mylog.write ((string) "adding exit value: " + (yyvsp[(2) - (2)].str));
		free ((yyvsp[(2) - (2)].str));
	}
    break;

  case 19:

/* Line 1455 of yacc.c  */
#line 136 "parser.yy"
    {
		my_params->set_break_lines ((yyvsp[(2) - (2)].str));
		mylog.write ((string) "breaking lines to a width of: " + (yyvsp[(2) - (2)].str));
		free ((yyvsp[(2) - (2)].str));
	}
    break;

  case 20:

/* Line 1455 of yacc.c  */
#line 144 "parser.yy"
    {
		my_params->set_export_long_options (true);
		mylog.write ((string) "exporting long options struct");
	}
    break;

  case 21:

/* Line 1455 of yacc.c  */
#line 151 "parser.yy"
    {
		my_params->set_no_struct (true);
		mylog.write ((string) "do not auto generate a struct / class for parsing results");
	}
    break;

  case 22:

/* Line 1455 of yacc.c  */
#line 158 "parser.yy"
    {
		my_params->set_global_callback ((yyvsp[(1) - (1)].str));
		mylog.write ((string) "setting global callback: " + (yyvsp[(1) - (1)].str));
	}
    break;

  case 25:

/* Line 1455 of yacc.c  */
#line 169 "parser.yy"
    {
		param = new Clparam; mylog.write ("reading parameter...");
	}
    break;

  case 26:

/* Line 1455 of yacc.c  */
#line 173 "parser.yy"
    {
		add_param_to_list ();
	}
    break;

  case 28:

/* Line 1455 of yacc.c  */
#line 180 "parser.yy"
    {
		param->set_type ((yyvsp[(2) - (3)].p));
		dump_param_type ((yyvsp[(2) - (3)].p));
	}
    break;

  case 32:

/* Line 1455 of yacc.c  */
#line 192 "parser.yy"
    {
		param->set_default_value ((yyvsp[(1) - (1)].str));
		mylog.write ((string) "  default value: " + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 34:

/* Line 1455 of yacc.c  */
#line 199 "parser.yy"
    {
		param->set_callback ((yyvsp[(1) - (1)].str));
		mylog.write ((string) "  callback: " + (yyvsp[(1) - (1)].str));
	}
    break;

  case 36:

/* Line 1455 of yacc.c  */
#line 205 "parser.yy"
    {
		param->set_store_longindex (true);
		mylog.write ((string) "  longindex for this parameter must be stored");
	}
    break;

  case 38:

/* Line 1455 of yacc.c  */
#line 211 "parser.yy"
    {
		param->set_add_flag (true);
		mylog.write ((string) "  this parameter also gets a flag");
	}
    break;

  case 39:

/* Line 1455 of yacc.c  */
#line 216 "parser.yy"
    {
		param->set_do_not_document (true);
		mylog.write ((string) "  do not document this parameter");
	}
    break;

  case 45:

/* Line 1455 of yacc.c  */
#line 232 "parser.yy"
    {
		param->set_err_msg ((yyvsp[(1) - (1)].str));
		mylog.write ((string) "  conversion error message: " + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 46:

/* Line 1455 of yacc.c  */
#line 239 "parser.yy"
    {
		param->set_err_msg (string("\"") + (yyvsp[(1) - (1)].str) + '\"');
		mylog.write ((string) "  conversion error message: \"" + (yyvsp[(1) - (1)].str) + '\"');
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 47:

/* Line 1455 of yacc.c  */
#line 246 "parser.yy"
    {
		param->set_err_msg ((yyvsp[(1) - (3)].str));
		mylog.write ((string) "  conversion error message: " + (yyvsp[(1) - (3)].str));
		param->set_err_msg_conv ((yyvsp[(3) - (3)].str));
		mylog.write ((string) "  conversion function for erraneous argument: " + (yyvsp[(3) - (3)].str));
		free ((yyvsp[(1) - (3)].str));
		free ((yyvsp[(3) - (3)].str));
	}
    break;

  case 48:

/* Line 1455 of yacc.c  */
#line 256 "parser.yy"
    {
		param->set_err_msg (string("\"") + (yyvsp[(1) - (3)].str) + '\"');
		mylog.write ((string) "  conversion error message: \"" + (yyvsp[(1) - (3)].str) + '\"');
		param->set_err_msg_conv ((yyvsp[(3) - (3)].str));
		mylog.write ((string) "  conversion function for erraneous argument: " + (yyvsp[(3) - (3)].str));
		free ((yyvsp[(1) - (3)].str));
		free ((yyvsp[(3) - (3)].str));
	}
    break;

  case 49:

/* Line 1455 of yacc.c  */
#line 267 "parser.yy"
    {
		param->set_comment ((yyvsp[(3) - (4)].str));
		mylog.write ((string) "  comment: " + (yyvsp[(3) - (4)].str));
		free ((yyvsp[(3) - (4)].str));
	}
    break;

  case 50:

/* Line 1455 of yacc.c  */
#line 274 "parser.yy"
    {
		mylog.write ((string) "including genparse file" + (yyvsp[(2) - (2)].str));
		free ((yyvsp[(2) - (2)].str));
	}
    break;

  case 51:

/* Line 1455 of yacc.c  */
#line 281 "parser.yy"
    {
		param->set_short_reps ((yyvsp[(1) - (1)].str));
		dump_short_reps ((yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));

	}
    break;

  case 52:

/* Line 1455 of yacc.c  */
#line 288 "parser.yy"
    {
		param->set_longopt_value (longopt_value.get ());
		param->set_long_only (true);
	}
    break;

  case 53:

/* Line 1455 of yacc.c  */
#line 293 "parser.yy"
    {
		param->set_short_reps ((yyvsp[(1) - (3)].str));
		dump_short_reps ((yyvsp[(1) - (3)].str));
		free ((yyvsp[(1) - (3)].str));
	}
    break;

  case 55:

/* Line 1455 of yacc.c  */
#line 302 "parser.yy"
    {
		param->set_short_has_arg (optional_argument);
	}
    break;

  case 56:

/* Line 1455 of yacc.c  */
#line 306 "parser.yy"
    {
		param->set_short_has_arg (no_argument);
	}
    break;

  case 60:

/* Line 1455 of yacc.c  */
#line 317 "parser.yy"
    {
		param->set_opt_name ((yyvsp[(2) - (2)].str));
		free ((yyvsp[(2) - (2)].str));
	}
    break;

  case 61:

/* Line 1455 of yacc.c  */
#line 322 "parser.yy"
    {
		param->set_opt_name ((yyvsp[(2) - (2)].str));
		free ((yyvsp[(2) - (2)].str));
	}
    break;

  case 62:

/* Line 1455 of yacc.c  */
#line 329 "parser.yy"
    {
		param->set_opt_name_in_square_braces (true);
	}
    break;

  case 63:

/* Line 1455 of yacc.c  */
#line 334 "parser.yy"
    {}
    break;

  case 64:

/* Line 1455 of yacc.c  */
#line 336 "parser.yy"
    {
		param->set_long_has_arg (optional_argument);
	}
    break;

  case 65:

/* Line 1455 of yacc.c  */
#line 340 "parser.yy"
    {
		param->set_long_has_arg (no_argument);
	}
    break;

  case 66:

/* Line 1455 of yacc.c  */
#line 346 "parser.yy"
    {
		param->set_long_rep ((yyvsp[(1) - (1)].str));
		mylog.write ((string) "  long representation: " + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 67:

/* Line 1455 of yacc.c  */
#line 352 "parser.yy"
    {
		param->set_long_rep ((yyvsp[(1) - (1)].str));
		mylog.write ((string) "  long representation: " + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 68:

/* Line 1455 of yacc.c  */
#line 359 "parser.yy"
    { (yyval.p) = int_type; }
    break;

  case 69:

/* Line 1455 of yacc.c  */
#line 361 "parser.yy"
    {
		if (my_params->get_use_gnulib ())
			(yyval.p) = long_type;
		else
			yyerror ("type long only supported if GNU Portability Library is used "
				 "(option --gnulib enables it)");
	}
    break;

  case 70:

/* Line 1455 of yacc.c  */
#line 369 "parser.yy"
    {
		if (my_params->get_use_gnulib ())
			(yyval.p) = ulong_type;
		else
			yyerror ("type ulong only supported if GNU Portability Library is used "
				 "(option --gnulib enables it)");
	}
    break;

  case 71:

/* Line 1455 of yacc.c  */
#line 377 "parser.yy"
    {
		if (my_params->get_use_gnulib ())
			(yyval.p) = intmax_type;
		else
			yyerror ("type intmax_t only supported if GNU Portability Library is used "
				 "(option --gnulib enables it)");
	}
    break;

  case 72:

/* Line 1455 of yacc.c  */
#line 385 "parser.yy"
    {
		if (my_params->get_use_gnulib ())
			(yyval.p) = uintmax_type;
		else
			yyerror ("type uintmax_t only supported if GNU Portability Library is used "
				 "(option --gnulib enables it)");
	}
    break;

  case 73:

/* Line 1455 of yacc.c  */
#line 392 "parser.yy"
    { (yyval.p) = float_type; }
    break;

  case 74:

/* Line 1455 of yacc.c  */
#line 394 "parser.yy"
    {
		if (my_params->get_use_gnulib ())
			(yyval.p) = double_type;
		else
			yyerror ("type double only supported if GNU Portability Library is used "
				 "(option --gnulib enables it)");
	}
    break;

  case 75:

/* Line 1455 of yacc.c  */
#line 401 "parser.yy"
    { (yyval.p) = string_type; }
    break;

  case 76:

/* Line 1455 of yacc.c  */
#line 402 "parser.yy"
    { (yyval.p) = char_type; }
    break;

  case 77:

/* Line 1455 of yacc.c  */
#line 403 "parser.yy"
    { (yyval.p) = flag_type; }
    break;

  case 80:

/* Line 1455 of yacc.c  */
#line 408 "parser.yy"
    { (yyval.str) = (yyvsp[(2) - (3)].str); }
    break;

  case 82:

/* Line 1455 of yacc.c  */
#line 415 "parser.yy"
    {
		param->set_low_range ((yyvsp[(1) - (3)].str));
		mylog.write ((string)"  parameter range: " + (yyvsp[(1) - (3)].str) + "..");
		free ((yyvsp[(1) - (3)].str));
	}
    break;

  case 84:

/* Line 1455 of yacc.c  */
#line 425 "parser.yy"
    {
		param->set_high_range ((yyvsp[(1) - (1)].str));
		mylog.write ((string)"  parameter range: .." + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 85:

/* Line 1455 of yacc.c  */
#line 431 "parser.yy"
    {
		param->set_high_range ((yyvsp[(1) - (1)].str));
		mylog.write ((string)"  parameter range: .." + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 89:

/* Line 1455 of yacc.c  */
#line 443 "parser.yy"
    { (yyval.str) = (yyvsp[(1) - (2)].str); }
    break;

  case 90:

/* Line 1455 of yacc.c  */
#line 447 "parser.yy"
    {
		param->add_description ((yyvsp[(1) - (1)].str), false);
		mylog.write ((string) "  description: " + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 91:

/* Line 1455 of yacc.c  */
#line 453 "parser.yy"
    {
		param->add_description ((yyvsp[(1) - (1)].str), true);
		mylog.write ((string) "  description starting in 1st column: " + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 95:

/* Line 1455 of yacc.c  */
#line 466 "parser.yy"
    {
		my_params->append_usage_line ((yyvsp[(1) - (1)].str));
		mylog.write ((string)"  usage string:" + (yyvsp[(1) - (1)].str));
		free ((yyvsp[(1) - (1)].str));
	}
    break;

  case 98:

/* Line 1455 of yacc.c  */
#line 478 "parser.yy"
    {
		param->add_code_line ((yyvsp[(1) - (2)].str));
		mylog.write ((string)"  code string:" + (yyvsp[(1) - (2)].str));
		free ((yyvsp[(1) - (2)].str));
	}
    break;

  case 99:

/* Line 1455 of yacc.c  */
#line 484 "parser.yy"
    {
		param->add_code_line ("");
		mylog.write ((string)"  code string:");
	}
    break;

  case 100:

/* Line 1455 of yacc.c  */
#line 491 "parser.yy"
    {
	}
    break;

  case 101:

/* Line 1455 of yacc.c  */
#line 494 "parser.yy"
    {
		(yyval.str) = strdup ((string ("(")).c_str ());
	}
    break;

  case 102:

/* Line 1455 of yacc.c  */
#line 498 "parser.yy"
    {
		(yyval.str) = strdup ((string (")")).c_str ());
	}
    break;

  case 103:

/* Line 1455 of yacc.c  */
#line 502 "parser.yy"
    {
		(yyval.str) = strdup ((string ((yyvsp[(1) - (2)].str)) + (yyvsp[(2) - (2)].str)).c_str ());
		free ((yyvsp[(1) - (2)].str));
		free ((yyvsp[(2) - (2)].str));
	}
    break;



/* Line 1455 of yacc.c  */
#line 2224 "parser.cc"
      default: break;
    }
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (YY_("syntax error"));
#else
      {
	YYSIZE_T yysize = yysyntax_error (0, yystate, yychar);
	if (yymsg_alloc < yysize && yymsg_alloc < YYSTACK_ALLOC_MAXIMUM)
	  {
	    YYSIZE_T yyalloc = 2 * yysize;
	    if (! (yysize <= yyalloc && yyalloc <= YYSTACK_ALLOC_MAXIMUM))
	      yyalloc = YYSTACK_ALLOC_MAXIMUM;
	    if (yymsg != yymsgbuf)
	      YYSTACK_FREE (yymsg);
	    yymsg = (char *) YYSTACK_ALLOC (yyalloc);
	    if (yymsg)
	      yymsg_alloc = yyalloc;
	    else
	      {
		yymsg = yymsgbuf;
		yymsg_alloc = sizeof yymsgbuf;
	      }
	  }

	if (0 < yysize && yysize <= yymsg_alloc)
	  {
	    (void) yysyntax_error (yymsg, yystate, yychar);
	    yyerror (yymsg);
	  }
	else
	  {
	    yyerror (YY_("syntax error"));
	    if (yysize != 0)
	      goto yyexhaustedlab;
	  }
      }
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      if (yychar <= YYEOF)
	{
	  /* Return failure if at end of input.  */
	  if (yychar == YYEOF)
	    YYABORT;
	}
      else
	{
	  yydestruct ("Error: discarding",
		      yytoken, &yylval);
	  yychar = YYEMPTY;
	}
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule which action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;


      yydestruct ("Error: popping",
		  yystos[yystate], yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  *++yyvsp = yylval;


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined(yyoverflow) || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
     yydestruct ("Cleanup: discarding lookahead",
		 yytoken, &yylval);
  /* Do not reclaim the symbols of the rule which action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
		  yystos[*yyssp], yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  /* Make sure YYID is used.  */
  return YYID (yyresult);
}



/* Line 1675 of yacc.c  */
#line 508 "parser.yy"


int yyerror (char *s)
{
  cerr << s << " in " << yyfilename << ": " << yylineno << endl;
  return 1;
}

void dump_short_reps (char *s)
{
  mylog.write (LOG_OPTION_NO_CR, "  short representation: "); 
  mylog.write (LOG_OPTION_NO_TS, s);
}

void add_param_to_list ()
{
  mylog.write ("done reading parameter...adding to list");
  my_params->add (*param);
  delete param;
}

void dump_param_type (param_type p)
{
  mylog.write (LOG_OPTION_NO_CR, "  parameter type: ");
  switch (p)
    {
    case int_type:
      mylog.write (LOG_OPTION_NO_TS, "int");
      break;
    case long_type:
      mylog.write (LOG_OPTION_NO_TS, "long int");
      break;
    case ulong_type:
      mylog.write (LOG_OPTION_NO_TS, "unsigned long int");
      break;
    case intmax_type:
      mylog.write (LOG_OPTION_NO_TS, "intmax_t");
      break;
    case uintmax_type:
      mylog.write (LOG_OPTION_NO_TS, "uintmax_t");
      break;
    case float_type:
      mylog.write (LOG_OPTION_NO_TS, "float");
      break;
    case double_type:
      mylog.write (LOG_OPTION_NO_TS, "double");
      break;
    case string_type:
      mylog.write (LOG_OPTION_NO_TS, "string");
      break;
    case char_type:
      mylog.write (LOG_OPTION_NO_TS, "char");
      break;
    case flag_type:
      mylog.write (LOG_OPTION_NO_TS, "flag");
      break;
    default:
      break;
    }
}

